@@ -7,6 +7,7 @@ from hypothesis.strategies import characters
 
 from agentMET4FOF.agents import AgentMET4FOF
 from agentMET4FOF.network import AgentNetwork
+from agentMET4FOF.utils import Backend
 
 
 @given(
@@ -15,7 +16,7 @@ from agentMET4FOF.network import AgentNetwork
     )
 )
 def test_naming_agents_for_mesa(name):
-    agent_network = AgentNetwork(dashboard_modules=False, backend="mesa")
+    agent_network = AgentNetwork(dashboard_modules=False, backend=Backend.MESA)
 
     agent = agent_network.add_agent(name=name, agentType=AgentMET4FOF)
     assert agent_network.get_agent(name).name == agent.name == name
@@ -36,3 +37,12 @@ def test_naming_agents_for_osbrain(agent_network):
         == agent.get_attr("name")
         == random_name.replace(" ", "_")
     )
+
+
+def test_naming_a_mesa_agents_with_a_single_space():
+    agent_network = AgentNetwork(dashboard_modules=False, backend=Backend.MESA)
+
+    agent = agent_network.add_agent(name=" ", agentType=AgentMET4FOF)
+    assert agent_network.get_agent("_").name == agent.name == "_"
+
+    agent_network.shutdown()
